@@ -1,6 +1,7 @@
 #include "AlarmPickDialog.h"
 
 #include <QPushButton>
+#include <QMaemo5Style>
 
 #include "CWrapper.h"
 
@@ -13,6 +14,10 @@ AlarmPickDialog::AlarmPickDialog(int seconds, QWidget *parent) :
 
     this->setAttribute(Qt::WA_DeleteOnClose);
 
+    QPalette palette;
+    palette.setColor(QPalette::WindowText, QMaemo5Style::standardColor("SecondaryTextColor"));
+    ui->timeLabel->setPalette(palette);
+
     ui->hoursBox->setValue(seconds / 3600);
     ui->minutesBox->setValue(seconds % 3600 / 60);
     ui->secondsBox->setValue(seconds % 60);
