@@ -1,5 +1,6 @@
 #include "EventWindow.h"
 
+#include <QMaemo5InformationBox>
 #include <QMaemo5Style>
 
 #include <QDateTime>
@@ -175,26 +176,31 @@ void EventWindow::reload()
     CCalendar *calendar = CMulticalendar::MCInstance()->getCalendarById(event->getCalendarId(), error);
     QIcon calendarIcon = QIcon::fromTheme(CWrapper::colorIcon(calendar->getCalendarColor()));
     QString calendarName = QString::fromUtf8(calendar->getCalendarName().c_str());
+    CalendarType calendarType = calendar->getCalendarType();
     delete calendar;
 
     ui->calendarIcon->setPixmap(calendarIcon.pixmap(calendarIcon.availableSizes().first()));
-    ui->calendarInfo->setText(calendarName);
+    ui->calendarInfo->setText(calendarName + " (" + CWrapper::calendarType(calendarType) + ")");
 }
 
 void EventWindow::gotoPrevEvent()
 {
     int error;
     int calendarId;
+    time_t stamp;
 
     CComponent *component = CMulticalendar::MCInstance()->getPrevNextComponent(instance.event->getId(),
                                                                                instance.stamp,
                                                                                true,
-                                                                               calendarId, instance.stamp, error);
+                                                                               calendarId, stamp, error);
 
     if (component) {
         delete instance.component;
         instance.component = component;
+        instance.stamp = stamp;
         reload();
+    } else {
+        QMaemo5InformationBox::information(this, tr("No more events"), 1000);
     }
 }
 
@@ -202,16 +208,20 @@ void EventWindow::gotoNextEvent()
 {
     int error;
     int calendarId;
+    time_t stamp;
 
     CComponent *component = CMulticalendar::MCInstance()->getPrevNextComponent(instance.event->getId(),
                                                                                instance.stamp,
                                                                                false,
-                                                                               calendarId, instance.stamp, error);
+                                                                               calendarId, stamp, error);
 
     if (component) {
         delete instance.component;
         instance.component = component;
+        instance.stamp = stamp;
         reload();
+    } else {
+        QMaemo5InformationBox::information(this, tr("No more events"), 1000);
     }
 }
 
