@@ -140,6 +140,13 @@ void WeekWidget::reload()
     populateAllDay();
     populate();
 
+    // Create a hint profile from the accumulated widgets
+    hintProfile.populate(componentWidgets);
+    componentWidgets.clear();
+
+    // The proper height can change depending on the number of all-day widgets
+    this->setFixedHeight(sizeHint().height());
+
     this->update();
 }
 
@@ -147,12 +154,14 @@ void WeekWidget::populateAllDay()
 {
     allDaySlots = 1;
 
+    if (allDayInstances.empty()) return;
+
     WeekLayoutWindow window;
     unsigned int currentComponent = 0;
     QDate date = firstDate();
     const QDate lastDate = this->lastDate();
 
-    // Iterate over weekday rows
+    // Iterate over weekday columns
     for (int d = 0; d < NumWeekdays; d++) {
         // Move to a new day
         window.move(date);
@@ -172,8 +181,11 @@ void WeekWidget::populateAllDay()
                 // Calculate how many days of the component are visible
                 int componentLength;
                 if (window.instances[i]->component->getType() == E_EVENT) {
-                    const QDate endDate = QDateTime::fromTime_t(window.instances[i]->end()).date();
-                    componentLength = 1 + qMin(date.daysTo(endDate) + 1,
+                    QDateTime endDate = QDateTime::fromTime_t(window.instances[i]->end());
+                    if (window.instances[i]->duration() > 0)
+                        endDate = endDate.addSecs(-1);
+
+                    componentLength = 1 + qMin(date.daysTo(endDate.date()) + 1,
                                                date.daysTo(lastDate));
                 } else {
                     componentLength = 1;
@@ -193,13 +205,11 @@ void WeekWidget::populateAllDay()
 
         allDaySlots = qMax(allDaySlots, (int) window.instances.size());
     }
-
-    this->setFixedHeight(sizeHint().height());
 }
 
 void WeekWidget::populate()
 {
-    if (components.empty()) return;
+    if (instances.empty()) return;
 
     QHash<ComponentInstance*,ComponentWidget*> masterWidgets;
     masterWidgets.reserve(components.size());
@@ -213,9 +223,10 @@ void WeekWidget::populate()
 
         // Analyze the profile frame by frame
         for (unsigned int f = 0; f < weekProfile.frames.size()-1; f++) {
-            // A frame which is on the previous day can onyl be useful if it is
-            // the first one to cover another day
-            if (weekProfile.frames[f+1].stamp <= dayStartStamp) continue;
+            // A frame which is on the previous day can only be useful if it is
+            // the first one to cover another day. This can be determined by
+            // checking if its successor is on the second day.
+            if (weekProfile.frames[f+1].stamp < dayStartStamp) continue;
 
             // Take a frame from which events will be built
             WeekProfile::Frame frame = weekProfile.frames[f];
@@ -224,17 +235,19 @@ void WeekWidget::populate()
             if (frame.stamp > dayEndStamp) break;
 
             // Look at each component in the selected frame
-            for (int c = 0; c < FrameSize; c++) {
+            for (int i = 0; i < FrameSize; i++) {
                 // Take a look at a slot, check if it is occupied and if a new widget should be created
-                if (frame.components[c] && (dayFirstFrame || frame.initial[c])) {
-                    ComponentInstance *instances = frame.components[c];
+                if (frame.instances[i] && (dayFirstFrame || frame.initial[i])) {
+                    ComponentInstance *instance = frame.instances[i];
 
                     // Ignore components which do not reach this day
-                    if (instances->end() < dayStartStamp) continue;
+                    if (instance->end() < dayStartStamp
+                    ||  instance->end() == dayStartStamp && instance->duration() > 0)
+                        continue;
 
                     // Calculate the key moments of the component, relative to this day
-                    const int eventStart  = qMax((time_t) 0, (instances->stamp - dayStartStamp));
-                    const int eventLength = qMin((time_t) NumHours*60*60 - eventStart, instances->end() - qMax(dayStartStamp, instances->stamp));
+                    const int eventStart  = qMax((time_t) 0, (instance->stamp - dayStartStamp));
+                    const int eventLength = qMin((time_t) NumHours*60*60 - eventStart, instance->end() - qMax(dayStartStamp, instance->stamp));
 
                     // Initialize component size parameters to the worst case
                     int maxPofileWidth = 1;
@@ -245,7 +258,7 @@ void WeekWidget::populate()
                     // this component by peeking into future frames
                     for (unsigned int ff = f; ff < weekProfile.frames.size(); ff++) {
                         // There is only a need to look as far as this component reaches
-                        if (weekProfile.frames[ff].components[c] != frame.components[c]) break;
+                        if (weekProfile.frames[ff].instances[i] != frame.instances[i]) break;
                         // Width on each day can be different, look no further than this day
                         if (weekProfile.frames[ff].stamp > dayEndStamp) break;
 
@@ -255,10 +268,10 @@ void WeekWidget::populate()
                         minProfileIndent = qMin(minProfileIndent, weekProfile.frames[ff].indent());
 
                         // Find the first occupied slot to the right
-                        for (int cc = c+1; cc < FrameSize; cc++) {
-                            if (weekProfile.frames[ff].components[cc]) {
+                        for (int ii = i+1; ii < FrameSize; ii++) {
+                            if (weekProfile.frames[ff].instances[ii]) {
                                 // The amount of minimum free space will be the component width numerator
-                                const int freeSlots = cc - c;
+                                const int freeSlots = ii - i;
                                 if (freeSlots < minFreeSlots)
                                     minFreeSlots = freeSlots;
                                 break;
@@ -267,27 +280,27 @@ void WeekWidget::populate()
                     }
 
                     // Make sure that the amount of free slots does not take unoccupied border slots into account
-                    minFreeSlots = qMin(minFreeSlots, maxPofileWidth-c);
+                    minFreeSlots = qMin(minFreeSlots, maxPofileWidth-i);
 
                     // Take the indent into account to get the real usable width
                     maxPofileWidth -= minProfileIndent;
 
-                    const int eventX = eventBaseX + (c-minProfileIndent) * CellWidth / maxPofileWidth;
+                    const int eventX = eventBaseX + (i-minProfileIndent) * CellWidth / maxPofileWidth;
                     const int eventY = (allDayRowHeight() + SpacingHeight) + (CellHeight + SpacingHeight) * eventStart/60/60;
                     const int eventW = CellWidth * minFreeSlots / maxPofileWidth;
                     const int eventH = qMax(CellHeight / 2, (CellHeight + SpacingHeight) * eventLength/60/60 - SpacingHeight);
 
-                    const int color = palette[instances->component->getCalendarId()];
+                    const int color = palette[instance->component->getCalendarId()];
 
-                    ComponentWidget *widget = new ComponentWidget(instances, color, eventX, eventY, eventW, eventH, this);
+                    ComponentWidget *widget = new ComponentWidget(instance, color, eventX, eventY, eventW, eventH, this);
                     componentWidgets.push_back(widget);
                     widget->show();
 
                     // Create a master-slave relationship if necessary
-                    if (ComponentWidget *master = masterWidgets.value(instances)) {
+                    if (ComponentWidget *master = masterWidgets.value(instance)) {
                         master->addSlave(widget);
                     } else {
-                        masterWidgets[instances] = widget;
+                        masterWidgets[instance] = widget;
                     }
                 }
             }
@@ -295,10 +308,6 @@ void WeekWidget::populate()
             dayFirstFrame = false;
         }
     }
-
-    // Create a hint profile from the accumulated widgets
-    hintProfile.populate(componentWidgets);
-    componentWidgets.clear();
 }
 
 // Returns the first day shown by the widget
